//Bibliothek für die WLAN-Verbindung
#include <ESP8266WiFi.h>

//Bibliothek, Objekt und Variable für den Sensor
#include "DHT.h"
#define DHTPIN 4
#define DHTTYPE DHT11
DHT dht(DHTPIN, DHTTYPE);

float temp;

//Daten des WLAN-Netzwerks
const char* ssid     = "Name deines Netzwerks";
const char* password = "Passwort deines Netzwerks";

// Port des Web Servers auf 80 setzen
WiFiServer server(80);

void setup() {
  Serial.begin(115200); //Seriellen Monitor starten

  dht.begin();

  //Mit dem WLAN-Netzwerk verbinden
  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.println("Ich verbinde mich mit dem Internet...");
  }
  Serial.println("Ich bin mit dem Internet verbunden!");

  //Lokale IP-Adresse im Seriellen Monitor ausgeben und Server starten
  Serial.println("");
  Serial.println("IP-Adresse: ");
  Serial.println(WiFi.localIP());

  server.begin();
}

void loop() {
  WiFiClient client = server.available();   //Auf Clients (Server-Aufrufe) warten

  if (client) {                             //Bei einem Aufruf des Servers...
    Serial.println("Anfrage von Client erhalten.");
    String currentLine = "";                //...String definieren für die Anfrage des Clients

    while (client.connected()) { //Loop, solange Client verbunden ist

      if (client.available()) {
        char c = client.read();             //Ein (1) Zeichen der Anfrage des Clients lesen
        Serial.write(c);                    //und es im Seriellen Monitor ausgeben
        if (c == '\n') {                    //bis eine Neue Zeile ausgegeben wird

          //Wenn der Client eine Leerzeile sendet, ist das Ende des HTTP Request erreicht
          if (currentLine.length() == 0) {

            //Der Server sendet nun eine Antwort an den Client
            client.println("HTTP/1.1 200 OK");
            client.println("Content-type:text/html");
            client.println("Connection: close");
            client.println();

            //Die Temperatur ermitteln
            temp = dht.readTemperature();
            Serial.print("Temperatur = ");
            Serial.print(temp);
            Serial.println(" *C");

            // Die Webseite anzeigen
            client.println("<!DOCTYPE html><html>");
            client.println("<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">");
            client.println("<meta charset=\"utf-8\"></head>");
            client.println("<body><h1 align=\"center\">Die aktuelle Temperatur</h1>");
            client.println("<p align=\"center\">");
            client.println(temp);
            client.println("°C</p>");
            client.println("</body></html>");

            //Die Antwort beenden
            client.println();
            // Den Loop beenden
            break;
          } else { //Bei einer neuen Zeile (keine Leerzeile), die Variable leeren
            currentLine = "";
          }
        } else if (c != '\r') {  //alles andere als eine Leerzeile wird
          currentLine += c;      //der Variablen hinzugefüht
        }
      }
    }
    // Die Verbindung beenden
    client.stop();
    Serial.println("Verbindung beendet.");
    Serial.println("");
  }
}
